<?php
// LiveUser: A framework for authentication and authorization in PHP applications
// Copyright (C) 2002-2003 Markus Wolff
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

/**
 * Class LiveUser_Admin_Auth_Common
 *
 * @author   Lukas Smith <smith@backendmedia.com>
 * @version  $Id: Common.php,v 1.2 2003/07/16 07:44:55 lsmith Exp $
 * @package  LiveUser
 * @category authentication
 */
class LiveUser_Admin_Auth_Common
{
    /**
     * Indicates if backend module initialized correctly. If yes,
     * TRUE, if not false. Backend module won't initialize if the
     * init value (usually an object or resource handle that
     * identifies the backend to be used) is not of the required
     * type.
     *
     * @var    boolean
     * @access public
     */
    var $init_ok = false;

    /**
     * Set posible encryption modes.
     *
     * $var array
     */
    var $encryptionModes = array('MD5'   => 'MD5',
                                 'PLAIN' => 'PLAIN');

    /**
     * Defines the algorhythm used for encrypting/decrypting
     * passwords. Default: "MD5".
     *
     * @var string
     */
    var $passwordEncryptionMode = 'MD5';

    /**
     * LiveUser_Admin_Auth_Common::liveUser_Auth()
     *
     * Class constructor. Feel free to override in backend subclasses.
     */
    function LiveUser_Admin_Auth_Common()
    {
        // I do nothing, override me plenty ;-)
    }

    /**
     * LiveUser_Admin_Auth_Common::decryptPW()
     *
     * Decrypts a password so that it can be compared with the user
     * input. Uses the algorhythm defined in the passwordEncryptionMode
     * property.
     *
     * @param  string $encryptedPW
     * @return string The decrypted password
     */
    function decryptPW($encryptedPW)
    {
        $decryptedPW = 'Encryption type not supported.';

        switch (strtoupper($this->passwordEncryptionMode)) {
            case 'PLAIN':
                $decryptedPW = $encryptedPW;
                break;
            case 'MD5':
                // MD5 can't be decoded, so return the string unmodified
                $decryptedPW = $encryptedPW;
                break;
        }

        return $decryptedPW;
    }

    /**
     * LiveUser_Admin_Auth_Common::encryptPW()
     *
     * Encrypts a password for storage in a backend container.
     * Uses the algorhythm defined in the passwordEncryptionMode
     * property.
     *
     * @param string $plainPW
     * @return string The encrypted password
     */
    function encryptPW($plainPW)
    {
        $encryptedPW = 'Encryption type not supported.';

        switch (strtoupper($this->passwordEncryptionMode)) {
            case 'PLAIN':
                $encryptedPW = $plainPW;
                break;
            case 'MD5':
                $encryptedPW = md5($plainPW);
                break;
        }

        return $encryptedPW;
    }

    /**
     * LiveUser_Admin_Auth_Common::getProperty()
     *
     * Function returns the inquired value if it exists in the class.
     *
     * @param  string   Name of the property to be returned.
     * @return mixed    NULL, a value or an array.
     */
    function getProperty($what)
    {
        $that = null;
        if (isset($this->$what)) {
            $that = $this->$what;
        }
        return $that;
    }

    /**
     * Adds a new user to Auth.
     *
     * @access  public
     * @param   string     $handle    Handle (username).
     * @param   string     $password  Password (optional).
     * @param   boolean    $active    Sets the user active (1) or not (0) (optional).
     * @param   int        $type      User type (constants defined in Perm/Common.php) (optional).
     * @return  mixed                 Users auth ID on success, error object if not.
     */
    function addUser($handle, $password = '', $active = 1, $type = 1)
    {
        return PEAR::raiseError(null, LIVEUSER_NOT_SUPPORTED, null, E_USER_WARNING,
            'Method not supported by this container', 'LiveUser', true);
    }

    /**
     * Removes an existing user from Auth.
     *
     * @access  public
     * @param   string   $authId   Auth user ID of the user that should be removed.
     * @return  mixed              True on success, error object if not.
     */
    function removeUser($authId)
    {
        return PEAR::raiseError(null, LIVEUSER_NOT_SUPPORTED, null, E_USER_WARNING,
            'Method not supported by this container', 'LiveUser', true);
    }

    /**
     * Changes user data in auth table.
     *
     * @access  public
     * @access  string     $authId    Auth user ID.
     * @param   string     $handle    Handle (username) (optional).
     * @param   string     $password  Password (optional).
     * @param   boolean    $active    Sets the user active (1) or not (0) (optional).
     * @return  mixed                 True on success, error object if not.
     */
    function changeUser($authId, $handle = '', $password = '', $active = NULL)
    {
        return PEAR::raiseError(null, LIVEUSER_NOT_SUPPORTED, null, E_USER_WARNING,
            'Method not supported by this container', 'LiveUser', true);
    }

    /**
     * Gets all users with handle, password, authId, permId, currentLogin,
     * lastLogin, isActive and individual rights.
     *
     * The array will look like this:
     * $userData[0]['authId']       = 'wujha433gawefawfwfiuj2ou9823r98h';
     *             ['handle']       = 'myLogin';
     *             ['password']     = 'd346gs2gwaeiuhaeiuuweijfjuwaefhj';
     *             ['currentLogin'] = 1254801292; (Unix timestamp)
     *             ['lastLogin']    = 1254801292; (Unix timestamp)
     *             ['isActive']     = 1; (1 = yes, 0 = no)
     *
     * @access  public
     * @return  mixed                 Array with user data or error object.
     */
    function getAllUsers()
    {
        return PEAR::raiseError(null, LIVEUSER_NOT_SUPPORTED, null, E_USER_WARNING,
            'Method not supported by this container', 'LiveUser', true);
    }
}
?>